==> haskell-hslua-objectorientation-2.3.0-88-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-objectorientation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-objectorientation
version:              2.3.0
visibility:           public
id:                   hslua-objectorientation-2.3.0-HDHCeekCVj39UanDIcyE4s
key:                  hslua-objectorientation-2.3.0-HDHCeekCVj39UanDIcyE4s
license:              MIT
copyright:            © 2021-2023 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Object orientation tools for HsLua
description:
    Expose Haskell objects to Lua with an object oriented
    interface.

category:             Foreign
abi:                  107dd0903407bc0c3d074663411626a6
exposed:              True
exposed-modules:
    HsLua.ObjectOrientation HsLua.ObjectOrientation.Operation

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-objectorientation-2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-objectorientation-2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-objectorientation-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-objectorientation
hs-libraries:         HShslua-objectorientation-2.3.0-HDHCeekCVj39UanDIcyE4s
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    exceptions-0.10.5 hslua-core-2.3.1-BaIvpfGeoSs6jiepDBO6qT
    hslua-marshalling-2.3.1-AmQJxNxb5SvIMK9lDMCSa7
    hslua-typing-0.1.1-IbYfHnO1lXyB7b07RVjd7q mtl-2.2.2 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-objectorientation/html/hslua-objectorientation.haddock

haddock-html:         /usr/share/doc/haskell-hslua-objectorientation/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-objectorientation-2.3.0-89-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-objectorientation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-objectorientation
version:              2.3.0
visibility:           public
id:                   hslua-objectorientation-2.3.0-8mLkfq4DiHxAdzgXZ9LwJw
key:                  hslua-objectorientation-2.3.0-8mLkfq4DiHxAdzgXZ9LwJw
license:              MIT
copyright:            © 2021-2023 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Object orientation tools for HsLua
description:
    Expose Haskell objects to Lua with an object oriented
    interface.

category:             Foreign
abi:                  7bb568a5cef9690b7f61aafe48f7943d
exposed:              True
exposed-modules:
    HsLua.ObjectOrientation HsLua.ObjectOrientation.Operation

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-objectorientation-2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-objectorientation-2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-objectorientation-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-objectorientation
hs-libraries:         HShslua-objectorientation-2.3.0-8mLkfq4DiHxAdzgXZ9LwJw
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    exceptions-0.10.5 hslua-core-2.3.1-Fc3hUeMzwrzD2zPByqV3Tq
    hslua-marshalling-2.3.1-3lwUpI0L8lcFUiaobcEJOA
    hslua-typing-0.1.1-56eY5V3ITFgHfHKLRMUqFV mtl-2.2.2 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-objectorientation/html/hslua-objectorientation.haddock

haddock-html:         /usr/share/doc/haskell-hslua-objectorientation/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
